@@ -23,7 +23,7 @@ import urllib2
 
 try:
     import json
-except:
+except ImportError:
     import simplejson as json
     
 class ResourceError(Exception):
@@ -43,7 +43,19 @@ def get_page(url, headers = None):
         return urllib2.urlopen(urllib2.Request(url, None, headers)).read()
     except:
         raise ResourceError('{"error": "Unable to retrieve page from %s"}' % url)
-    
+
+def get_redirect(url, headers = None):
+    try:
+        if headers is None:
+            request = urllib2.Request(url)
+        else:
+            request = urllib2.Request(url, None, headers)
+
+        request.get_method = lambda : 'HEAD'
+        return urllib2.urlopen(request).geturl()
+    except:
+        return url
+
 def list_videos(url):
     if not url:
         raise ResourceError('{"error": "No URL specified"}')
@@ -168,13 +180,13 @@ def list_streams(url):
     
     try:
         sources = json.loads(get_page(url).split('sources:')[1].strip().split('},')[0] + '}')
-    
+        
         for source in sources:
             stream = {}
             stream['description'] = 'MP4 audio/video'
             stream['height'] = int(source.split('p')[0])
             stream['id'] = source
-            stream['url'] = sources[source]
+            stream['url'] = get_redirect(sources[source])
             stream['width'] = stream['height'] * 4 / 3
             streams.append(stream)
     except:
